/*
 * Fortanix SDKMS REST API
 *
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations.
 *
 * API version: 1.0.0-20171218
 * Contact: support@fortanix.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package sdkms

import (
	"context"
	"net/http"
	"testing"
)

func TestAuthenticationApiService_Authorize(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx context.Context
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             AuthResponse
		wantCheckFields  []string //Name of fields from json object AuthResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Authentication Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
			},
			wantCheckFields:  []string{"EntityId"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &AuthenticationApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.Authorize(tt.args.ctx)
			if (err != nil) != tt.wantErr {
				t.Errorf("AuthenticationApiService.Authorize() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("AuthenticationApiService.Authorize() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("AuthenticationApiService.Authorize() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestAuthenticationApiService_CheckHealth(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx context.Context
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name            string
		fields          fields
		args            args
		want            *http.Response
		wantCheckFields []string //Name of fields from json object *http.Response to be verified.
		wantCheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr         bool
	}{
		{
			name: "Check Health Test - Positive",
			fields: fields{
				client: Client,
			},
			want:            &http.Response{StatusCode: 204},
			wantCheckFields: []string{"StatusCode"},
			wantCheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &AuthenticationApiService{
				client: tt.fields.client,
			}
			got, err := a.CheckHealth(tt.args.ctx)
			if (err != nil) != tt.wantErr {
				t.Errorf("AuthenticationApiService.CheckHealth() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("AuthenticationApiService.CheckHealth() = %v, want %v", got, tt.want)
			}
		})
	}
}

func TestAuthenticationApiService_GetServerVersion(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx context.Context
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             VersionResponse
		wantCheckFields  []string //Name of fields from json object VersionResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Check Version Test - Positive",
			fields: fields{
				client: Client,
			},
			wantCheckFields:  []string{"Version", "ApiVersion", "ServerMode"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &AuthenticationApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.GetServerVersion(tt.args.ctx)
			if (err != nil) != tt.wantErr {
				t.Errorf("AuthenticationApiService.GetServerVersion() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("AuthenticationApiService.GetServerVersion() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("AuthenticationApiService.GetServerVersion() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestAuthenticationApiService_SelectAccount(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body SelectAccountRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             SelectAccountResponse
		wantCheckFields  []string //Name of fields from json object SelectAccountResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "SelectAccount Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: SelectAccountRequest{AcctId: TestRequisites.AccountID},
			},
			wantCheckFields:  []string{},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &AuthenticationApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.SelectAccount(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("AuthenticationApiService.SelectAccount() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("AuthenticationApiService.SelectAccount() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("AuthenticationApiService.SelectAccount() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestAuthenticationApiService_Terminate(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx context.Context
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name            string
		fields          fields
		args            args
		want            *http.Response
		wantCheckFields []string //Name of fields from json object *http.Response to be verified.
		wantCheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr         bool
	}{
		{
			name: "Terminate Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
			},
			want:            &http.Response{StatusCode: 204},
			wantCheckFields: []string{"StatusCode"},
			wantCheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &AuthenticationApiService{
				client: tt.fields.client,
			}
			got, err := a.Terminate(tt.args.ctx)
			if (err != nil) != tt.wantErr {
				t.Errorf("AuthenticationApiService.Terminate() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("AuthenticationApiService.Terminate() = %v, want %v", got, tt.want)
			}
		})
	}
}

func TestAuthenticationApiService_Unlock2F(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx context.Context
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name            string
		fields          fields
		args            args
		want            *http.Response
		wantCheckFields []string //Name of fields from json object *http.Response to be verified.
		wantCheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr         bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &AuthenticationApiService{
				client: tt.fields.client,
			}
			got, err := a.Unlock2F(tt.args.ctx)
			if (err != nil) != tt.wantErr {
				t.Errorf("AuthenticationApiService.Unlock2F() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("AuthenticationApiService.Unlock2F() = %v, want %v", got, tt.want)
			}
		})
	}
}
