/*
 * Fortanix SDKMS REST API
 *
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations.
 *
 * API version: 1.0.0-20171218
 * Contact: support@fortanix.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package sdkms

import (
	"encoding/base64"
	"net/http"
	"testing"

	"golang.org/x/net/context"
)

func TestEncryptionAndDecryptionApiService_BatchDecrypt(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body []BatchDecryptRequestInner
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	RSADecryptRequest := DecryptRequest{Alg: &RSA, Cipher: TestRequisites.Cipher1, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))}
	AESDecryptRequest := DecryptRequest{Alg: &AES, Mode: &CBC, Cipher: TestRequisites.Cipher2, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             []BatchDecryptResponseInner
		wantCheckFields  []string //Name of fields from json object []BatchDecryptResponseInner to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "BatchDecrypt Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
				body: []BatchDecryptRequestInner{
					BatchDecryptRequestInner{
						Kid:     TestRequisites.RSAKeyID,
						Request: &RSADecryptRequest,
					},
					BatchDecryptRequestInner{
						Kid:     TestRequisites.AESKeyID,
						Request: &AESDecryptRequest,
					},
				},
			},
			want: []BatchDecryptResponseInner{
				BatchDecryptResponseInner{
					Status: 200,
				},
				BatchDecryptResponseInner{
					Status: 200,
				},
			},
			wantCheckFields:  []string{"Status"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.BatchDecrypt(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.BatchDecrypt() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.BatchDecrypt() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.BatchDecrypt() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_BatchEncrypt(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body []BatchEncryptRequestInner
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	RSAEncryptRequest := EncryptRequest{Alg: &RSA, Plain: TestRequisites.Plain1, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))}
	AESEncryptRequest := EncryptRequest{Alg: &AES, Mode: &CBC, Plain: TestRequisites.Plain1, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             []BatchEncryptResponseInner
		wantCheckFields  []string //Name of fields from json object []BatchEncryptResponseInner to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "BatchEncrypt Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
				body: []BatchEncryptRequestInner{
					BatchEncryptRequestInner{
						Kid:     TestRequisites.RSAKeyID,
						Request: &RSAEncryptRequest,
					},
					BatchEncryptRequestInner{
						Kid:     TestRequisites.AESKeyID,
						Request: &AESEncryptRequest,
					},
				},
			},
			want: []BatchEncryptResponseInner{
				BatchEncryptResponseInner{
					Status: 200,
				},
				BatchEncryptResponseInner{
					Status: 200,
				},
			},
			wantCheckFields:  []string{"Status"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.BatchEncrypt(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.BatchEncrypt() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.BatchEncrypt() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.BatchEncrypt() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_Decrypt(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  DecryptRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             DecryptResponse
		wantCheckFields  []string //Name of fields from json object DecryptResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Decrypt Test - RSA - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.RSAKeyID,
				body:  DecryptRequest{Alg: &RSA, Cipher: TestRequisites.RSACipher, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))},
			},
			want:             DecryptResponse{Plain: TestRequisites.Plain1},
			wantCheckFields:  []string{"Plain"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Decrypt Test - AES - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.AESKeyID,
				body:  DecryptRequest{Alg: &AES, Mode: &CBC, Cipher: TestRequisites.AESCipher, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))},
			},
			want:             DecryptResponse{Plain: TestRequisites.Plain1},
			wantCheckFields:  []string{"Plain"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Decrypt Test - DES - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.DESKeyID,
				body:  DecryptRequest{Alg: &DES, Mode: &CBC, Cipher: TestRequisites.DESCipher, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV8Len))},
			},
			want:             DecryptResponse{Plain: TestRequisites.Plain1},
			wantCheckFields:  []string{"Plain"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Decrypt Test - DES3 - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.DES3KeyID,
				body:  DecryptRequest{Alg: &DES3, Mode: &CBC, Cipher: TestRequisites.DES3Cipher, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV8Len))},
			},
			want:             DecryptResponse{Plain: TestRequisites.Plain1},
			wantCheckFields:  []string{"Plain"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.Decrypt(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.Decrypt() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.Decrypt() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.Decrypt() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_DecryptEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body DecryptRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	AESKey := SobjectDescriptor{Kid: TestRequisites.AESKeyID}
	RSAKey := SobjectDescriptor{Kid: TestRequisites.RSAKeyID}
	DESKey := SobjectDescriptor{Kid: TestRequisites.DESKeyID}
	DES3Key := SobjectDescriptor{Kid: TestRequisites.DES3KeyID}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             DecryptResponse
		wantCheckFields  []string //Name of fields from json object DecryptResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "DecryptEx Test - RSA - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: DecryptRequestEx{Key: &RSAKey, Alg: &RSA, Cipher: TestRequisites.RSACipher, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))},
			},
			want:             DecryptResponse{Plain: TestRequisites.Plain1},
			wantCheckFields:  []string{"Plain"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "DecryptEx Test - AES - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: DecryptRequestEx{Key: &AESKey, Mode: &CBC, Cipher: TestRequisites.AESCipher, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))},
			},
			want:             DecryptResponse{Plain: TestRequisites.Plain1},
			wantCheckFields:  []string{"Plain"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "DecryptEx Test - DES - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: DecryptRequestEx{Key: &DESKey, Alg: &DES, Mode: &CBC, Cipher: TestRequisites.DESCipher, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV8Len))},
			},
			want:             DecryptResponse{Plain: TestRequisites.Plain1},
			wantCheckFields:  []string{"Plain"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Decrypt Test - DES3 - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: DecryptRequestEx{Key: &DES3Key, Alg: &DES3, Mode: &CBC, Cipher: TestRequisites.DES3Cipher, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV8Len))},
			},
			want:             DecryptResponse{Plain: TestRequisites.Plain1},
			wantCheckFields:  []string{"Plain"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.DecryptEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_DecryptFinal(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  DecryptFinalRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             DecryptFinalResponse
		wantCheckFields  []string //Name of fields from json object DecryptFinalResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.DecryptFinal(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptFinal() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptFinal() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptFinal() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_DecryptFinalEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body DecryptFinalRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             DecryptFinalResponse
		wantCheckFields  []string //Name of fields from json object DecryptFinalResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.DecryptFinalEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptFinalEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptFinalEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptFinalEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_DecryptInit(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  DecryptInitRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             DecryptInitResponse
		wantCheckFields  []string //Name of fields from json object DecryptInitResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.DecryptInit(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptInit() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptInit() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptInit() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_DecryptInitEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body DecryptInitRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             DecryptInitResponse
		wantCheckFields  []string //Name of fields from json object DecryptInitResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.DecryptInitEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptInitEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptInitEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptInitEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_DecryptUpdate(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  DecryptUpdateRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             DecryptUpdateResponse
		wantCheckFields  []string //Name of fields from json object DecryptUpdateResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.DecryptUpdate(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptUpdate() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptUpdate() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptUpdate() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_DecryptUpdateEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body DecryptUpdateRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             DecryptUpdateResponse
		wantCheckFields  []string //Name of fields from json object DecryptUpdateResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.DecryptUpdateEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptUpdateEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptUpdateEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.DecryptUpdateEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_Encrypt(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  EncryptRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             EncryptResponse
		wantCheckFields  []string //Name of fields from json object EncryptResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Encrypt Test - RSA - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.RSAKeyID,
				body:  EncryptRequest{Alg: &RSA, Plain: TestRequisites.Plain1, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))},
			},
			wantCheckFields:  []string{"Cipher"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Encrypt Test - AES - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.AESKeyID,
				body:  EncryptRequest{Alg: &AES, Mode: &CBC, Plain: TestRequisites.Plain1, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV16Len))},
			},
			wantCheckFields:  []string{"Cipher"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Encrypt Test - DES - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.DESKeyID,
				body:  EncryptRequest{Alg: &DES, Mode: &CBC, Plain: TestRequisites.Plain1, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV8Len))},
			},
			wantCheckFields:  []string{"Cipher"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
		{
			name: "Encrypt Test - DES3 - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.DES3KeyID,
				body:  EncryptRequest{Alg: &DES3, Mode: &CBC, Plain: TestRequisites.Plain1, Iv: base64.StdEncoding.EncodeToString([]byte(TestRequisites.IV8Len))},
			},
			wantCheckFields:  []string{"Cipher"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.Encrypt(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.Encrypt() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.Encrypt() got = %v, want %v", got, tt.want)
			} else {
				if tt.args.keyId == TestRequisites.RSAKeyID {
					TestRequisites.RSACipher = got.Cipher
				} else if tt.args.keyId == TestRequisites.AESKeyID {
					TestRequisites.AESCipher = got.Cipher
				} else if tt.args.keyId == TestRequisites.DESKeyID {
					TestRequisites.DESCipher = got.Cipher
				} else if tt.args.keyId == TestRequisites.DES3KeyID {
					TestRequisites.DES3Cipher = got.Cipher
				}
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.Encrypt() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_EncryptEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body EncryptRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             EncryptResponse
		wantCheckFields  []string //Name of fields from json object EncryptResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.EncryptEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_EncryptFinal(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  EncryptFinalRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             EncryptFinalResponse
		wantCheckFields  []string //Name of fields from json object EncryptFinalResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.EncryptFinal(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptFinal() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptFinal() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptFinal() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_EncryptFinalEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body EncryptFinalRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             EncryptFinalResponse
		wantCheckFields  []string //Name of fields from json object EncryptFinalResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.EncryptFinalEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptFinalEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptFinalEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptFinalEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_EncryptInit(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  EncryptInitRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             EncryptInitResponse
		wantCheckFields  []string //Name of fields from json object EncryptInitResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.EncryptInit(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptInit() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptInit() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptInit() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_EncryptInitEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body EncryptInitRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             EncryptInitResponse
		wantCheckFields  []string //Name of fields from json object EncryptInitResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.EncryptInitEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptInitEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptInitEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptInitEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_EncryptUpdate(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  EncryptUpdateRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             EncryptUpdateResponse
		wantCheckFields  []string //Name of fields from json object EncryptUpdateResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.EncryptUpdate(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptUpdate() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptUpdate() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptUpdate() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestEncryptionAndDecryptionApiService_EncryptUpdateEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body EncryptUpdateRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             EncryptUpdateResponse
		wantCheckFields  []string //Name of fields from json object EncryptUpdateResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		// TODO: Add test cases.
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &EncryptionAndDecryptionApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.EncryptUpdateEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptUpdateEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptUpdateEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("EncryptionAndDecryptionApiService.EncryptUpdateEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}
