/*
 * Fortanix SDKMS REST API
 *
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations.
 *
 * API version: 1.0.0-20171218
 * Contact: support@fortanix.com
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package sdkms

import (
	"net/http"
	"testing"

	"golang.org/x/net/context"
)

func TestSignAndVerifyApiService_BatchSign(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body []SignRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	RSAKey := SobjectDescriptor{Kid: TestRequisites.RSAKeyID}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             []BatchSignResponseInner
		wantCheckFields  []string //Name of fields from json object []BatchSignResponseInner to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "BatchSign Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
				body: []SignRequestEx{
					SignRequestEx{
						Key:     &RSAKey,
						HashAlg: &SHA1,
						Hash:    TestRequisites.Hash1,
					},
					SignRequestEx{
						Key:     &RSAKey,
						HashAlg: &SHA256,
						Hash:    TestRequisites.Hash2,
					},
				},
			},
			want: []BatchSignResponseInner{
				BatchSignResponseInner{
					Status: 200,
				},
				BatchSignResponseInner{
					Status: 200,
				},
			},
			wantCheckFields:  []string{"Status"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SignAndVerifyApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.BatchSign(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SignAndVerifyApiService.BatchSign() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SignAndVerifyApiService.BatchSign() got = %v, want %v", got, tt.want)
			} else {
				TestRequisites.Sign1 = got[0].Body.Signature
				TestRequisites.Sign1 = got[1].Body.Signature
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SignAndVerifyApiService.BatchSign() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSignAndVerifyApiService_BatchVerify(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body []VerifyRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	RSAKey := SobjectDescriptor{Kid: TestRequisites.RSAKeyID}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             []BatchVerifyResponseInner
		wantCheckFields  []string //Name of fields from json object []BatchVerifyResponseInner to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "BatchVerify Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx: GetContext(t),
				body: []VerifyRequestEx{
					VerifyRequestEx{
						Key:       &RSAKey,
						HashAlg:   &SHA1,
						Hash:      TestRequisites.Hash1,
						Signature: TestRequisites.Sign1,
					},
					VerifyRequestEx{
						Key:       &RSAKey,
						HashAlg:   &SHA256,
						Hash:      TestRequisites.Hash2,
						Signature: TestRequisites.Sign2,
					},
				},
			},
			want: []BatchVerifyResponseInner{
				BatchVerifyResponseInner{
					Status: 200,
				},
				BatchVerifyResponseInner{
					Status: 200,
				},
			},
			wantCheckFields:  []string{"Status"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SignAndVerifyApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.BatchVerify(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SignAndVerifyApiService.BatchVerify() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SignAndVerifyApiService.BatchVerify() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SignAndVerifyApiService.BatchVerify() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSignAndVerifyApiService_Sign(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  SignRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             SignResponse
		wantCheckFields  []string //Name of fields from json object SignResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Sign Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.RSAKeyID,
				body:  SignRequest{HashAlg: &SHA1, Hash: TestRequisites.Hash1},
			},
			wantCheckFields:  []string{"Signature"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SignAndVerifyApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.Sign(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SignAndVerifyApiService.Sign() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SignAndVerifyApiService.Sign() got = %v, want %v", got, tt.want)
			} else {
				TestRequisites.Sign1 = got.Signature
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SignAndVerifyApiService.Sign() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSignAndVerifyApiService_SignEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body SignRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	RSAKey := SobjectDescriptor{Kid: TestRequisites.RSAKeyID}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             SignResponse
		wantCheckFields  []string //Name of fields from json object SignResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "SignEx Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: SignRequestEx{Key: &RSAKey, HashAlg: &SHA1, Hash: TestRequisites.Hash1},
			},
			wantCheckFields:  []string{"Signature"},
			wantCheckValues:  false,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SignAndVerifyApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.SignEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SignAndVerifyApiService.SignEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SignAndVerifyApiService.SignEx() got = %v, want %v", got, tt.want)
			} else {
				TestRequisites.Sign1 = got.Signature
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SignAndVerifyApiService.SignEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSignAndVerifyApiService_Verify(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx   context.Context
		keyId string
		body  VerifyRequest
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             VerifyResponse
		wantCheckFields  []string //Name of fields from json object VerifyResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "Verify Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:   GetContext(t),
				keyId: TestRequisites.RSAKeyID,
				body:  VerifyRequest{HashAlg: &SHA1, Hash: TestRequisites.Hash1, Signature: TestRequisites.Sign1},
			},
			want:             VerifyResponse{Result: true},
			wantCheckFields:  []string{"Result"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SignAndVerifyApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.Verify(tt.args.ctx, tt.args.keyId, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SignAndVerifyApiService.Verify() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SignAndVerifyApiService.Verify() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SignAndVerifyApiService.Verify() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}

func TestSignAndVerifyApiService_VerifyEx(t *testing.T) {
	type fields struct {
		client *APIClient
	}
	type args struct {
		ctx  context.Context
		body VerifyRequestEx
	}

	teardownTestCase := setupTestCase(t)
	defer teardownTestCase(t)

	RSAKey := SobjectDescriptor{Kid: TestRequisites.RSAKeyID}

	testCases := []struct {
		name             string
		fields           fields
		args             args
		want             VerifyResponse
		wantCheckFields  []string //Name of fields from json object VerifyResponse to be verified.
		wantCheckValues  bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		want1            *http.Response
		want1CheckFields []string //Name of fields from json object *http.Response to be verified.
		want1CheckValues bool     //Flag to indicate for matching values of fields specified above. If false then only check for non-null/not-empty.
		wantErr          bool
	}{
		{
			name: "VerifyEx Test - Positive",
			fields: fields{
				client: Client,
			},
			args: args{
				ctx:  GetContext(t),
				body: VerifyRequestEx{Key: &RSAKey, HashAlg: &SHA1, Hash: TestRequisites.Hash1, Signature: TestRequisites.Sign1},
			},
			want:             VerifyResponse{Result: true},
			wantCheckFields:  []string{"Result"},
			wantCheckValues:  true,
			want1:            &http.Response{StatusCode: 200},
			want1CheckFields: []string{"StatusCode"},
			want1CheckValues: true,
		},
	}

	for _, tt := range testCases {
		t.Run(tt.name, func(t *testing.T) {
			a := &SignAndVerifyApiService{
				client: tt.fields.client,
			}
			got, got1, err := a.VerifyEx(tt.args.ctx, tt.args.body)
			if (err != nil) != tt.wantErr {
				t.Errorf("SignAndVerifyApiService.VerifyEx() error = %v, wantErr %v", err, tt.wantErr)
				return
			}
			if !IsMatching(tt.want, got, tt.wantCheckFields, tt.wantCheckValues) {
				t.Errorf("SignAndVerifyApiService.VerifyEx() got = %v, want %v", got, tt.want)
			}
			if !IsMatching(tt.want1, got1, tt.want1CheckFields, tt.want1CheckValues) {
				t.Errorf("SignAndVerifyApiService.VerifyEx() got1 = %v, want %v", got1, tt.want1)
			}
		})
	}
}
